@@ -1,4 +1,4 @@
-# Copyright (C) 2020  Brodie Gaslam
+# Copyright (C) 2022 Brodie Gaslam
 # 
 # This file is part of "unitizer"
 # 
@@ -212,8 +212,9 @@ get_unitizer.unitizer_results <- function(store.id) {
 #' Infers Possible Unitizer Path From Context
 #'
 #' Used by most \code{unitizer} functions that operate on \code{unitizer}s to
-#' make it easy to specify the most likely intended \code{unitizer} in a
-#' package or a directory.
+#' make it easy in interactive use to specify the most likely intended
+#' \code{unitizer} in a package or a directory.  For `R CMD check` and similar
+#' testing should not rely on this functionality.
 #'
 #' This is implemented as an S3 generic to allow third parties to define
 #' inference methods for other types of \code{store.id}, but the documentation
@@ -485,12 +486,12 @@ is_package_dir <- function(name, has.tests=FALSE) {
 
   TRUE
 }
-get_package_dir <- function(name=getwd(), has.tests=FALSE) {
+get_package_dir <- function(name=getwd(), has.tests=FALSE, exists=FALSE) {
   stopifnot(
     is.character(name), !any(is.na(name)), is.TF(has.tests),
     as.logical(length(name))
   )
-  name <- normalize_path(name, mustWork=FALSE)
+  name <- normalize_path(name, mustWork=FALSE, exists=exists)
   if(length(name) > 1L) name <- attr(unique_path(name), "common_dir")
   is.package <- FALSE
   prev.dir <- par.dir <- name
